% PROPADATA is a script for propagating retrieved pulses
% through real material.  It plots before and after amplitudes
% and phases in both domains.  A retrieved Speck.Dat file is
% required for the ELOAD command to function.

warning off;
PhaseBlank = 0.005;

[L,EL,SpeckFile] = eload;
L0 = L(length(L)./2 +1);
[W,ES] = ToConstFreqSpc(L,EL);
ES = quickscale(ES);
ET = quickscale(ifftc(ES));
dT = 2*pi./(W(end) - W(1));
T = dT.*[-length(W)/2:length(W)/2-1];

% % To simulate a typical GRENOUILLE, use:
direction = -1;
ESNew = quickscale(betaGREN(ltow(W),ES,direction));
%
% Change the 'direction' to 1 for forward propagation.
% Change the 'direction' to -1 for backward propagation.

% % To simulate just one chunk of material, use:
% len = 2.4;
% mat = 'FUSED SILICA';
% ESNew = quickscale(propagate(Wavelen,ES,len,mat));

ETNew = quickscale(ifftc(ESNew));

TemporalFWHMbefore = sprintf('FWHM = %6.1f fs',fwhm(IandP(ET),T));
TemporalFWHMafter = sprintf('FWHM = %6.1f fs',fwhm(IandP(ETNew),T));
SpectralFWHMbefore = sprintf('FWHM = %6.1f nm',fwhm(IandP(ES),ltow(W)));
SpectralFWHMafter = sprintf('FWHM = %6.1f nm',fwhm(IandP(ESNew),ltow(W)));


figure(43);clf;
% Before (back)propagation
subplot 231;
plotfrog(ET,ET,T,L0);
subplot 232;
plotcmplx(T,ET,[],[],PhaseBlank);
title(TemporalFWHMbefore);
subplot 233
plotcmplx(LtoW(W),ES,[],[],PhaseBlank);
title(SpectralFWHMbefore);

% After (back)propagation
subplot 234;
plotfrog(ETNew,ETNew,T,L0);
subplot 235;
plotcmplx(T,ETNew,[],[],PhaseBlank);
title(TemporalFWHMafter);
subplot 236
plotcmplx(LtoW(W),ESNew,[],[],PhaseBlank);
title(SpectralFWHMafter);

% Colormap HSV2 is for screens, HSV3 is for printing
colormap(hsv3);
warning on;
