function [W,E,L2] = ToConstFreqSpc(L,E,u)
%TOCONSTFREQSPC Converts E fome constant wavelength to constant angular frequency spacing.
%	[W,E,L2]=TOCONSTWAVESPC(L,E,U) Converts E(L) to E(W) where E
%	is the electric field, W is the angular frequency array, L is the
%	wavelength array, L2 is the wavelengths corresponding to W,
%	and U is the units on the speed of light (defaults to 'nm/fs').

%	$Revision: 1.7 $ $Date: 2002/05/09 18:44:05 $
%
%	$Log: ToConstFreqSpc.m,v $
%	Revision 1.7  2002/05/09 18:44:05  pat
%	Changed to angular frequencies.
%	
%	Revision 1.6  2002/04/30 22:25:58  zeekec
%	Used ltof()
%	
%	Revision 1.5  2002/04/30 16:18:25  pat
%	Corrected help.
%	
%	Revision 1.4  2001/08/22 22:38:57  zeekec
%	isrow error
%	
%	Revision 1.3  2001/08/21 16:53:51  zeekec
%	Misc
%	
%	Revision 1.2  2001/08/16 00:25:44  zeekec
%	Updated help
%	
%	Revision 1.1  2001/08/15 23:39:14  zeekec
%	Added function
%	

error(nargchk(2,3,nargin));

if (nargin < 3) | isempty(u)
	u = 'nm/fs';
end

wl = ltow(max(L),u);
wh = ltow(min(L),u);
w0 = mean([wl wh]);
w0 = const_c(u);

W = linspace(wl,wh,length(L));

if iscolumn(L)
	W = W';
end

L2 = ltow(W);
W2 = ltow(L);
C = W.^2 / w0^2;

w = find(W2 > 0);

if isrow(L)
	E = spline(L(w) , E(:,w) , L2 )  .* repmat(C,size(E,1),1);
else
	E = spline(L(w)', E(w,:)', L2')' .* repmat(C,1,size(E,2));
end

