function X = center(X, varargin)
%CENTER centers the array.
%	CENTER(X) returns X centered on its first moment.
%
%	CENTER(X, METHOD) returns X centered by METHOD.  Defaults
%		to first moment, 'moment,' can also center on the maximum,'max.'
%
%	CENTER(X, METHOD, ROTMETH) returns X centered by METHOD.  Rotates
%		array using ROTMETH.  Defaults to circular, 'circ.'  Currently
%		only 'circ' is supported.

%	$Revision: 1.6 $ $Date: 2002/05/09 16:28:00 $
%
%	$Log: center.m,v $
%	Revision 1.6  2002/05/09 16:28:00  zeekec
%	*** empty log message ***
%	
%	Revision 1.5  2002/04/30 16:19:02  pat
%	Works on rows and colums now.
%	
%	Revision 1.4  2001/11/16 17:48:23  zeekec
%	Centered properly for FFTC
%	
%	Revision 1.3  2001/11/15 21:32:30  zeekec
%	New ParseVarargin
%	
%	Revision 1.2  2001/10/31 18:08:24  zeekec
%	Changed to ParseVarargin implementation.
%	
%	Revision 1.1  2001/10/19 18:22:03  zeekec
%	Added function
%	

error(nargchk(1,3,nargin));

[method, rotmeth] = ParseVarargin(varargin,'moment','circ');

N = length(X);

% cent = floor(N / 2) + 2;

L = (-N/2 : N/2-1);

switch lower(method)
case 'max'
	[c,I] = max(X);
	I = L(I);
	
case 'moment'
	I = floor(sum(abs(X(:)) .* L(:)) / sum(abs(X(:))));
	
otherwise
	error(['Unknown centering method, ', method, '.']);
end

switch lower(rotmeth)
case 'circ'
	if isrow(X)
		X = circshift(X, [0, -I]);
	else
		X = circshift(X, -I);
	end
	
otherwise
	error(['Unknown shift method, ', rotmeth, '.']);
end

