function [axout,h1,h2] = plotcmplxI(x,z,varargin)
%PLOTCMPLXI Graphs intensity labels on the left and phase labels on the right.
%   PLOTCMPLXI(X,Z) plots ABS(Z).^2 versus X with y-axis labeling
%   on the left and plots UNWRAP(ANGLE(Z)) versus X with y-axis 
%   labeling on the right.
%
%   PLOTCMPLXI(X,Z,@FUN) uses the plotting function FUN for the intensity plot
%   instead of PLOT to produce each plot.  FUN should be a 
%   function handle to a plotting function, e.g. @plot, @semilogx,
%   @semilogy, @loglog ,@stem, etc. that accepts the syntax H = FUN(X,Y).
%
%   PLOTCMPLXI(X,Z,@FUN1,@FUN2) uses FUN1(X,ABS(Z).^2) to plot the data for
%   the left axes and FUN2(X,UNWRAP(ANGLE(Z))) to plot the data for
%   the right axes.
%
%   [AX,H1,H2] = PLOTCMPLXI(...) returns the handles of the two axes created in
%   AX and the handles of the graphics objects from each plot in H1
%   and H2. AX(1) is the left axes and AX(2) is the right axes.  
%
%   See also PLOTCMPLX, PLOT, PLOTYY, @.

%	$Revision: 1.6 $ $Date: 2002/05/09 17:53:07 $
%
%	$Log: plotcmplxI.m,v $
%	Revision 1.6  2002/05/09 17:53:07  zeekec
%	*** empty log message ***
%	
%	Revision 1.5  2002/05/09 16:27:46  zeekec
%	Added phase blanking
%	
%	Revision 1.4  2002/04/25 16:36:04  zeekec
%	Removed extra tick marks on the right.
%	Unfortunately removed the top line too.
%	
%	Revision 1.3  2002/04/25 16:27:15  zeekec
%	Changed phase to -phase and set the phase to zero at the peak intensity.
%	
%	Revision 1.1  2002/02/06 18:40:00  zeekec
%	Moved from misc.
%	
%	Revision 1.6  2002/02/05 22:11:03  pat
%	Added SetTight and autoscaling to both axes.
%	
%	Revision 1.5  2001/11/21 00:04:56  zeekec
%	*** empty log message ***
%	
%	Revision 1.4  2001/09/07 19:01:49  zeekec
%	Changed to VARARGIN implementation.
%	Added phase label.
%	
%	Revision 1.3  2001/07/26 19:44:30  zeekec
%	Changed implementation to a switch statment.
%	Changed behavior for one plotting function.
%	
%	Revision 1.2  2001/07/10 01:10:00  zeekec
%	Library cleanup.  Added, deleted, and moved files.
%	

error(nargchk(2,5,nargin))

[fun1, fun2, blank] = ParseVarargin(varargin,@plot,@plot, -1);

if isrow(x)
	x = x.';
	z = z.';
end

Inten = abs(z).^2;

phi = -unwrap(angle(z));

for k = 1:size(phi,2)
	phi(:,k) = phi(:,k) - phi(maxindex(Inten(:,k)),k);
	
	if blank > 0
		phi(find(Inten(:,k)<blank),k) = NaN;
	end
end

[ax,h1,h2] = plotyy(x, Inten, x, phi, fun1, fun2);

set(get(ax(2),'YLabel'),'String','Phase (Rad)','Rotation',270,'VerticalAlignment','middle');
set(ax(1),'box','off')
SetTight(ax(1));
SetTight(ax(2));
set(ax(1),'YTickMode','auto');
set(ax(2),'YTickMode','auto');

hold_state = ishold;
set(gcf,'nextplot','add')
ax(3) = axes('position',get(ax(2),'position'));
set(ax(3),'color','none', 'xgrid','off','ygrid','off','box','on')
set(ax(3),'XTickMode','manual','YTickMode','manual')

% DeleteProxy(3) = text('parent',ax(3),'visible','off',...
%                        'tag','PlotyyDeleteProxy',...
%                        'handlevisibility','off',...
%         'deletefcn','try;delete(get(gcbo,''userdata''));end');
% set(DeleteProxy(2),'userdata',DeleteProxy(2));

if ~hold_state, hold off, end

set(gcf,'currentaxes',ax(1));

if nargout > 0, axout = ax; end

